@@ -12,8 +12,10 @@ class TestIMKServer (TestCase):
         # NOTE: I have no idea if the tests will pass there, this
         # is just to avoid false negatives on 10.5
         # See also: Radar #6783035
-        self.failUnlessIsInstance(IMKDelegateClass, unicode)
-        self.failUnlessIsInstance(IMKControllerClass, unicode)
+        self.assertIsIn('IMKDelegateClass', globals())
+        self.assertIsInstance(IMKDelegateClass, unicode)
+        self.assertIsIn('IMKControllerClass', globals())
+        self.assertIsInstance(IMKControllerClass, unicode)
 
 
 if __name__ == "__main__":
